@@ -33,7 +33,7 @@ rosdep library and command-line tool
 
 from __future__ import print_function
 
-__version__ = '0.9.6'
+__version__ = '0.10.0'
 
 import sys
 
@@ -68,11 +68,12 @@ def create_default_installer_context(verbose=False):
     from .platforms import opensuse
     from .platforms import osx
     from .platforms import pip
+    from .platforms import gem
     from .platforms import redhat
     from .platforms import source
 
     platform_mods = [arch, cygwin, debian, gentoo, opensuse, osx, redhat]
-    installer_mods = [source, pip] + platform_mods
+    installer_mods = [source, pip, gem] + platform_mods
 
     context = InstallerContext()
     context.set_verbose(verbose)
